==> fizmo-0.8.1.tar.gz: fizmo-0.8.1/fizmo-sdl2/src/locales/fizmo_sdl2_locales.h <==

/* fizmo_sdl2_locales.c
 *
 * This file is part of fizmo.
 *
 * Copyright (c) 2011-2016 Christoph Ender.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#ifndef fizmo_sdl2_locales_c_INCLUDED
#define fizmo_sdl2_locales_c_INCLUDED

#define i18n_sdl2_SET_FOREGROUND_COLOR 0
#define i18n_sdl2_SET_BACKGROUND_COLOR 1
#define i18n_sdl2_SET_LEFT_MARGIN_SIZE 2
#define i18n_sdl2_SET_RIGHT_MARGIN_SIZE 3
#define i18n_sdl2_INVALID_CONFIGURATION_VALUE_P0S_FOR_P1S 4
#define i18n_sdl2_USAGE_DESCRIPTION 5
#define i18n_sdl2_VALID_OPTIONS_ARE 6
#define i18n_sdl2_SET_LOCALE_NAME_FOR_INTERPRETER_MESSAGES 7
#define i18n_sdl2_START_WITH_RANDOM_GENERATOR_IN_PREDICTABLE_MODE 8
#define i18n_sdl2_START_GAME_WITH_TRANSCRIPT_ENABLED 9
#define i18n_sdl2_LIBFIZMO_VERSION_P0S 10
#define i18n_sdl2_LOCALES_AVAILIABLE 11
#define i18n_sdl2_MORE_PROMPT 12
#define i18n_sdl2_SCORE 13
#define i18n_sdl2_TURNS 14
#define i18n_sdl2_NUMBER_OF_COLOR_COMBINATIONS_AVAILABLE_P0D 15
#define i18n_sdl2_COLORS_AVAILABLE 16
#define i18n_sdl2_INVALID_COLOR_NAME 17
#define i18n_sdl2_SHOW_HELP_MESSAGE_AND_EXIT 18
#define i18n_sdl2_USE_BOLD_FOR_BRIGHT_FOREGROUND_COLORS 19
#define i18n_sdl2_USE_BLINK_FOR_BRIGHT_BACKGROUND_COLORS 20
#define i18n_sdl2_DONT_USE_COLORS 21
#define i18n_sdl2_ENABLE_COLORS 22
#define i18n_sdl2_NO_STORIES_REGISTERED_PLUS_HELP 23
#define i18n_sdl2_SPACE_FOR_NEXT_PAGE 24
#define i18n_sdl2_B_FOR_LAST_PAGE 25
#define i18n_sdl2_USE_UMEM_FOR_SAVEGAMES 26
#define i18n_sdl2_DISABLE_X11_GRAPHICS 27
#define i18n_sdl2_USE_XTERM_TITLE 28
#define i18n_sdl2_FORCE_8BIT_SOUND 29
#define i18n_sdl2_DISABLE_SOUND 30
#define i18n_sdl2_SET_TANDY_FLAG 31
#define i18n_sdl2_DONT_UPDATE_STORY_LIST_ON_START 32
#define i18n_sdl2_SEARCH_DIRECTORY 33
#define i18n_sdl2_RECURSIVELY_SEARCH_DIRECTORY 34
#define i18n_sdl2_START_GAME_WITH_RECORDING_COMMANDS 35
#define i18n_sdl2_START_GAME_WITH_INPUT_FROM_FILE 36
#define i18n_sdl2_UPDATE_STORY_LIST_ON_START 37
#define i18n_sdl2_START_WITH_RANDOM_GENERATOR_IN_RANDOM_MODE 38
#define i18n_sdl2_SYNC_TRANSCRIPT 39
#define i18n_sdl2_FUNCTION_CALL_P0S_ABORTED_DUE_TO_ERROR 40
#define i18n_sdl2_FUNCTION_CALL_P0S_RETURNED_ERROR_P1D_P2S 41
#define i18n_sdl2_ERROR_P0D_OCCURED_BEFORE_READ_P1S 42
#define i18n_sdl2_UNKNOWN_ERROR_CASE 43
#define i18n_sdl2_FUNCTION_CALL_MALLOC_P2D_RETURNED_NULL_PROBABLY_OUT_OF_MEMORY 44
#define i18n_sdl2_FIZMO_SDL_VERSION_P0S 45
#define i18n_sdl2_LIBPIXELINTERFACE_VERSION_P0S 46
#define i18n_sdl2_LOCALE_SEARCH_PATH 47
#define i18n_sdl2_FILENAME_TO_READ_COMMANDS_FROM 48
#define i18n_sdl2_ENABLE_X11_INLINE_GRAPHICS 49
#define i18n_sdl2_LIBDRILBO_VERSION_P0S 50
#define i18n_sdl2_DISABLE_HYPHENATION 51
#define i18n_sdl2_SET_TRANSCRIPT_FILENAME 52
#define i18n_sdl2_FILENAME_TO_RECORD_INPUT_TO 53
#define i18n_sdl2_COULD_NOT_OPEN_OR_FIND_P0S 54
#define i18n_sdl2_SET_CURSOR_COLOR 55
#define i18n_sdl2_SET_FONT_SIZE 56
#define i18n_sdl2_SET_WINDOW_WIDTH 57
#define i18n_sdl2_SET_WINDOW_HEIGHT 58
#define i18n_sdl2_PROCESS_SDL2_EVENTS 59

extern z_ucs fizmo_sdl2_module_name[];

#endif // fizmo_sdl2_locales_c_INCLUDED

==> fizmo-0.8.2.tar.gz: fizmo-0.8.2/fizmo-sdl2/src/locales/fizmo_sdl2_locales.h <==

/* fizmo_sdl2_locales.c
 *
 * This file is part of fizmo.
 *
 * Copyright (c) 2011-2016 Christoph Ender.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#ifndef fizmo_sdl2_locales_c_INCLUDED
#define fizmo_sdl2_locales_c_INCLUDED

#define i18n_sdl2_SET_FOREGROUND_COLOR 0
#define i18n_sdl2_SET_BACKGROUND_COLOR 1
#define i18n_sdl2_SET_LEFT_MARGIN_SIZE 2
#define i18n_sdl2_SET_RIGHT_MARGIN_SIZE 3
#define i18n_sdl2_INVALID_CONFIGURATION_VALUE_P0S_FOR_P1S 4
#define i18n_sdl2_USAGE_DESCRIPTION 5
#define i18n_sdl2_VALID_OPTIONS_ARE 6
#define i18n_sdl2_SET_LOCALE_NAME_FOR_INTERPRETER_MESSAGES 7
#define i18n_sdl2_START_WITH_RANDOM_GENERATOR_IN_PREDICTABLE_MODE 8
#define i18n_sdl2_START_GAME_WITH_TRANSCRIPT_ENABLED 9
#define i18n_sdl2_LIBFIZMO_VERSION_P0S 10 // no longer used
#define i18n_sdl2_LOCALES_AVAILIABLE 11
#define i18n_sdl2_MORE_PROMPT 12
#define i18n_sdl2_SCORE 13
#define i18n_sdl2_TURNS 14
#define i18n_sdl2_NUMBER_OF_COLOR_COMBINATIONS_AVAILABLE_P0D 15
#define i18n_sdl2_COLORS_AVAILABLE 16
#define i18n_sdl2_INVALID_COLOR_NAME 17
#define i18n_sdl2_SHOW_HELP_MESSAGE_AND_EXIT 18
#define i18n_sdl2_USE_BOLD_FOR_BRIGHT_FOREGROUND_COLORS 19
#define i18n_sdl2_USE_BLINK_FOR_BRIGHT_BACKGROUND_COLORS 20
#define i18n_sdl2_DONT_USE_COLORS 21
#define i18n_sdl2_ENABLE_COLORS 22
#define i18n_sdl2_NO_STORIES_REGISTERED_PLUS_HELP 23
#define i18n_sdl2_SPACE_FOR_NEXT_PAGE 24
#define i18n_sdl2_B_FOR_LAST_PAGE 25
#define i18n_sdl2_USE_UMEM_FOR_SAVEGAMES 26
#define i18n_sdl2_DISABLE_X11_GRAPHICS 27
#define i18n_sdl2_USE_XTERM_TITLE 28
#define i18n_sdl2_FORCE_8BIT_SOUND 29
#define i18n_sdl2_DISABLE_SOUND 30
#define i18n_sdl2_SET_TANDY_FLAG 31
#define i18n_sdl2_DONT_UPDATE_STORY_LIST_ON_START 32
#define i18n_sdl2_SEARCH_DIRECTORY 33
#define i18n_sdl2_RECURSIVELY_SEARCH_DIRECTORY 34
#define i18n_sdl2_START_GAME_WITH_RECORDING_COMMANDS 35
#define i18n_sdl2_START_GAME_WITH_INPUT_FROM_FILE 36
#define i18n_sdl2_UPDATE_STORY_LIST_ON_START 37
#define i18n_sdl2_START_WITH_RANDOM_GENERATOR_IN_RANDOM_MODE 38
#define i18n_sdl2_SYNC_TRANSCRIPT 39
#define i18n_sdl2_FUNCTION_CALL_P0S_ABORTED_DUE_TO_ERROR 40
#define i18n_sdl2_FUNCTION_CALL_P0S_RETURNED_ERROR_P1D_P2S 41
#define i18n_sdl2_ERROR_P0D_OCCURED_BEFORE_READ_P1S 42
#define i18n_sdl2_UNKNOWN_ERROR_CASE 43
#define i18n_sdl2_FUNCTION_CALL_MALLOC_P2D_RETURNED_NULL_PROBABLY_OUT_OF_MEMORY 44
#define i18n_sdl2_FIZMO_SDL_VERSION_P0S 45
#define i18n_sdl2_LIBPIXELINTERFACE_VERSION_P0S 46
#define i18n_sdl2_LOCALE_SEARCH_PATH 47
#define i18n_sdl2_FILENAME_TO_READ_COMMANDS_FROM 48
#define i18n_sdl2_ENABLE_X11_INLINE_GRAPHICS 49
#define i18n_sdl2_LIBDRILBO_VERSION_P0S 50
#define i18n_sdl2_DISABLE_HYPHENATION 51
#define i18n_sdl2_SET_TRANSCRIPT_FILENAME 52
#define i18n_sdl2_FILENAME_TO_RECORD_INPUT_TO 53
#define i18n_sdl2_COULD_NOT_OPEN_OR_FIND_P0S 54
#define i18n_sdl2_SET_CURSOR_COLOR 55
#define i18n_sdl2_SET_FONT_SIZE 56
#define i18n_sdl2_SET_WINDOW_WIDTH 57
#define i18n_sdl2_SET_WINDOW_HEIGHT 58
#define i18n_sdl2_PROCESS_SDL2_EVENTS 59

extern z_ucs fizmo_sdl2_module_name[];

#endif // fizmo_sdl2_locales_c_INCLUDED
